@@ -3,11 +3,8 @@ package CloudFlare::Client;
 
 # Or Kavorka will explode
 use 5.014;
-use strict; use warnings;
+use strict; use warnings; no indirect 'fatal'; use namespace::autoclean;
 use mro 'c3';
-use IO qw(Handle File Dir);
-use autodie ':all'; no indirect 'fatal';
-use namespace::autoclean;
 
 use Readonly;
 use Moose; use MooseX::StrictConstructor;
@@ -20,9 +17,9 @@ use CloudFlare::Client::Exception::Upstream;
 use LWP::UserAgent       6.02;
 # This isn't used directly but we want the dependency
 use LWP::Protocol::https 6.02;
-use JSON::Any;
+use JSON::MaybeXS;
 
-our $VERSION = '0.05_2'; # TRIAL VERSION
+our $VERSION = '0.05_3'; # TRIAL VERSION
 
 # CF credentials
 has '_user' => (
@@ -65,8 +62,7 @@ method _apiCall($act is ro, %args is ro) {
         message => 'HTTPS request failed')
         unless $res->is_success;
     # Handle errors from CF
-    Readonly my $info =>
-        JSON::Any::->jsonToObj($res->decoded_content);
+    Readonly my $info => decode_json($res->decoded_content);
     CloudFlare::Client::Exception::Upstream::->throw(
         errorCode => $info->{err_code},
         message   => $info->{msg})
@@ -176,7 +172,7 @@ CloudFlare::Client - Object Orientated Interface to CloudFlare client API
 
 =head1 VERSION
 
-version 0.05_2
+version 0.05_3
 
 =head1 SYNOPSIS
 
