@@ -1,17 +1,14 @@
 package CloudFlare::Client::Exception::Connection;
 # ABSTRACT: CloudFlare API Connection Exception
 
-use strict; use warnings;
+use strict; use warnings; no indirect 'fatal'; use namespace::autoclean;
 use mro 'c3';
-use IO qw(Handle File Dir);
-use autodie ':all'; no indirect 'fatal';
-use namespace::autoclean;
 
 use Readonly;
 use Moose; use MooseX::StrictConstructor;
 use Types::Standard 'Str';
 
-our $VERSION = '0.05_2'; # TRIAL VERSION
+our $VERSION = '0.05_3'; # TRIAL VERSION
 
 extends 'Throwable::Error';
 
@@ -35,7 +32,7 @@ CloudFlare::Client::Exception::Connection - CloudFlare API Connection Exception
 
 =head1 VERSION
 
-version 0.05_2
+version 0.05_3
 
 =head1 SYNOPSIS
 
