@@ -1,17 +1,14 @@
 package CloudFlare::Client::Exception::Upstream;
 # ABSTRACT: Upstream CloudFlare API Exception
 
-use strict; use warnings;
+use strict; use warnings; no indirect 'FATAL'; use namespace::autoclean;
 use mro 'c3';
-use IO qw(Handle File Dir);
-use autodie ':all'; no indirect 'fatal';
-use namespace::autoclean;
 
 use Readonly;
 use Moose; use MooseX::StrictConstructor;
 use CloudFlare::Client::Types 'ErrorCode';
 
-our $VERSION = '0.05_2'; # TRIAL VERSION
+our $VERSION = '0.05_3'; # TRIAL VERSION
 
 extends 'Throwable::Error';
 
@@ -34,7 +31,7 @@ CloudFlare::Client::Exception::Upstream - Upstream CloudFlare API Exception
 
 =head1 VERSION
 
-version 0.05_2
+version 0.05_3
 
 =head1 SYNOPSIS
 
