@@ -1,11 +1,7 @@
 package CloudFlare::Client::Types;
 # ABSTRACT: Types for Cloudflare::Client
 
-use strict; use warnings;
-use mro 'c3';
-use IO qw(Handle File Dir);
-use autodie ':all'; no indirect 'fatal';
-use namespace::autoclean;
+use strict; use warnings; no indirect 'fatal'; use namespace::autoclean;
 
 use Type::Library -base, -declare => qw( CFCode ErrorCode);
 # Theres a bug about using undef as a hashref before this version
@@ -13,7 +9,7 @@ use Type::Utils 0.039_12 -all;
 use Types::Standard qw( Enum Maybe);
 use Readonly;
 
-our $VERSION = '0.05_2'; # TRIAL VERSION
+our $VERSION = '0.05_3'; # TRIAL VERSION
 
 class_type 'LWP::UserAgent';
 declare CFCode, as Enum[qw( E_UNAUTH E_INVLDINPUT E_MAXAPI)];
@@ -33,7 +29,7 @@ CloudFlare::Client::Types - Types for Cloudflare::Client
 
 =head1 VERSION
 
-version 0.05_2
+version 0.05_3
 
 =head1 SYNOPSIS
 
